diff --git a/src/Form/FieldsSettingsForm.php b/src/Form/FieldsSettingsForm.php
index 2bb9013..03fa48f 100644
--- a/src/Form/FieldsSettingsForm.php
+++ b/src/Form/FieldsSettingsForm.php
@@ -460,6 +460,7 @@ class FieldsSettingsForm extends ConfigFormBase {
     $this->config->save();
     // Save the settings, for fields which have a plugin selected.
     foreach ($fields as $field_key => $field_values) {
+      $settings = NULL;
       if ($field_values['plugin']['type'] != 'hidden') {
         // Get plugin settings. They lie either directly in submitted form
         // values (if the whole form was submitted while some plugin settings
@@ -476,15 +477,17 @@ class FieldsSettingsForm extends ConfigFormBase {
         }
         // If the settings are not set anywhere in the form state just save the
         // default configuration for the current plugin.
-        else {
+        elseif(!isset($plugin_settings)) {
           $settings = $plugin->defaultConfiguration();
         }
         // Build a FormState object and call the plugin submit handler.
-        $state = new FormState();
-        $state->setValues($settings);
-        $state->set('fields', $field_key);
+        if ($settings) {
+          $state = new FormState();
+          $state->setValues($settings);
+          $state->set('fields', $field_key);
 
-        $plugin->submitConfigurationForm($form, $state);
+          $plugin->submitConfigurationForm($form, $state);
+        }
       }
     }
 
diff --git a/src/Tests/DiffAdminFormsTest.php b/src/Tests/DiffAdminFormsTest.php
index 0417f1b..706f8c4 100644
--- a/src/Tests/DiffAdminFormsTest.php
+++ b/src/Tests/DiffAdminFormsTest.php
@@ -98,9 +98,33 @@ class DiffAdminFormsTest extends DiffTestBase {
       'fields[node.body][settings_edit_form][settings][compare_format]' => TRUE,
       'fields[node.body][settings_edit_form][settings][markdown]' => 'filter_xss_all',
     ];
-    $this->drupalPostForm(NULL, $edit, t('Update'));
+    $this->drupalPostAjaxForm(NULL, $edit, 'node.body_plugin_settings_update');
     $this->drupalPostForm(NULL, [], t('Save'));
     $this->assertText('Your settings have been saved.');
+
+    // Check the values were saved.
+    $this->drupalPostAjaxForm(NULL, [], 'node.body_settings_edit');
+    $this->assertFieldByName('fields[node.body][settings_edit_form][settings][markdown]', 'filter_xss_all');
+
+    // Edit another field.
+    $this->drupalPostAjaxForm(NULL, [], 'node.title_settings_edit');
+    $edit = [
+      'fields[node.title][settings_edit_form][settings][markdown]' => 'filter_xss_all',
+    ];
+    $this->drupalPostAjaxForm(NULL, $edit, 'node.title_plugin_settings_update');
+    $this->drupalPostForm(NULL, [], t('Save'));
+
+    // Check both fields and their config values.
+    $this->drupalPostAjaxForm(NULL, [], 'node.body_settings_edit');
+    $this->assertFieldByName('fields[node.body][settings_edit_form][settings][markdown]', 'filter_xss_all');
+    $this->drupalPostAjaxForm(NULL, [], 'node.title_settings_edit');
+    $this->assertFieldByName('fields[node.title][settings_edit_form][settings][markdown]', 'filter_xss_all');
+
+    $edit = [
+      'fields[node.sticky][plugin][type]' => 'hidden',
+    ];
+    $this->drupalPostForm(NULL, $edit, t('Save'));
+    $this->assertFieldByName('fields[node.sticky][plugin][type]', 'hidden');
   }
 
   /**
diff --git a/src/Tests/DiffViewModeTest.php b/src/Tests/DiffViewModeTest.php
index 37f64aa..3a6d51b 100644
--- a/src/Tests/DiffViewModeTest.php
+++ b/src/Tests/DiffViewModeTest.php
@@ -42,7 +42,11 @@ class DiffViewModeTest extends DiffTestBase {
     $edit = [
       'fields[body][region]' => 'hidden',
     ];
-    $this->drupalPostForm('admin/structure/types/manage/article/form-display', $edit, t('Save'));
+    $this->drupalPostForm('admin/structure/types/manage/article/display', $edit, t('Save'));
+    $edit = [
+      'fields[body][region]' => 'hidden',
+    ];
+    $this->drupalPostForm('admin/structure/types/manage/article/display/teaser', $edit, t('Save'));
 
     // Check the difference between the last two revisions.
     $this->drupalGet('node/' . $node->id() . '/revisions');

diff --git a/src/DiffBuilderManager.php b/src/DiffBuilderManager.php
index 0a286f0..8dcd901 100644
--- a/src/DiffBuilderManager.php
+++ b/src/DiffBuilderManager.php
@@ -6,9 +6,11 @@ use Drupal\Core\Cache\CacheBackendInterface;
 use Drupal\Core\Config\ConfigFactoryInterface;
 use Drupal\Core\Entity\EntityTypeManagerInterface;
 use Drupal\Core\Extension\ModuleHandlerInterface;
+use Drupal\Core\Field\BaseFieldDefinition;
 use Drupal\Core\Field\FieldDefinitionInterface;
 use Drupal\Core\Field\FieldStorageDefinitionInterface;
 use Drupal\Core\Plugin\DefaultPluginManager;
+use Drupal\field\Entity\FieldStorageConfig;
 
 /**
  * Plugin type manager for field diff builders.
@@ -125,7 +127,7 @@ class DiffBuilderManager extends DefaultPluginManager {
    *   The plugin instance, NULL if none.
    */
   public function createInstanceForFieldDefinition(FieldDefinitionInterface $field_definition, $bundle = NULL) {
-    $selected_plugin = $this->getSelectedPluginForFieldDefinition($field_definition, $bundle);
+    $selected_plugin = $this->getSelectedPluginForFieldStorageDefinition($field_definition->getFieldStorageDefinition(), $bundle);
     if ($selected_plugin && $selected_plugin['type'] != 'hidden') {
       if (!empty($selected_plugin['settings'])) {
         return $this->createInstance($selected_plugin['type'], $selected_plugin['settings']);
@@ -139,40 +141,40 @@ class DiffBuilderManager extends DefaultPluginManager {
   }
 
   /**
-   * Selects a default plugin for a field definition.
+   * Selects a default plugin for a field storage definition.
    *
-   * Checks the display configuration of the field to define if it should be
-   * displayed in the diff comparison.
+   * Checks if a plugin has been already selected for the field, otherwise
+   * chooses one between the plugins that can be applied to the field.
    *
    * @param \Drupal\Core\Field\FieldDefinitionInterface $field_definition
    *   The field definition.
    * @param string $bundle
    *   (optional) The entity bundle where to check the form display if no
    *   setting is set for a field.
    *
    * @return array
-   *   The plugin instance, NULL if none.
+   *   The selected plugin for the field.
    */
-  public function getSelectedPluginForFieldDefinition(FieldDefinitionInterface $field_definition, $bundle = NULL) {
-    $selected_plugin = NULL;
-    $visible = TRUE;
-    $field_key = $field_definition->getFieldStorageDefinition()->getTargetEntityTypeId() . '.' . $field_definition->getName();
-    // Do not check the entity form display if there are plugins settings stored
-    // for the current field.
+  public function getSelectedPluginForFieldStorageDefinition(FieldStorageDefinitionInterface $field_definition, $bundles = NULL) {
+    $plugin_options = $this->getApplicablePluginOptions($field_definition);
+    $field_key = $field_definition->getTargetEntityTypeId() . '.' . $field_definition->getName();
+    // If there is config stored then use it.
     if ($this->pluginsConfig->get('fields.' . $field_key)) {
-      $selected_plugin = $this->getSelectedPluginForFieldStorageDefinition($field_definition->getFieldStorageDefinition());
+      $selected_plugin = $this->pluginsConfig->get('fields.' . $field_key);
     }
     else {
-      // If entity is set load its form display settings.
-      if ($bundle) {
-        $storage = $this->entityTypeManager->getStorage('entity_form_display');
-        /** @var \Drupal\Core\Entity\Entity\EntityViewDisplay $display */
-        if ($display = $storage->load($field_definition->getTargetEntityTypeId() . '.' . $bundle . '.default')) {
-          $visible = (bool) $display->getComponent($field_definition->getName());
-        }
+      $selected_plugin['type'] = $this->getDefaultPluginForFieldStorageDefinition($field_definition, $bundles);
+      if ($selected_plugin['type'] === 'hidden') {
+        return ['type' => 'hidden'];
+      }
+    }
+
+    // Check if the plugin stored is still applicable for the fields.
+    if (!$selected_plugin || !in_array($selected_plugin['type'], array_keys($plugin_options))) {
+      if (!empty($plugin_options) && $selected_plugin['type'] != 'hidden') {
+        $selected_plugin['type'] = array_keys($plugin_options)[0];
       }
-      if ($visible) {
-        $selected_plugin = $this->getSelectedPluginForFieldStorageDefinition($field_definition->getFieldStorageDefinition());
+      else {
+        $selected_plugin['type'] = 'hidden';
       }
     }
     return $selected_plugin;
@@ -184,26 +186,29 @@ class DiffBuilderManager extends DefaultPluginManager {
    * Checks if a plugin has been already selected for the field, otherwise
    * chooses one between the plugins that can be applied to the field.
    *
-   * @param FieldStorageDefinitionInterface $field_definition
-   *   The field storage definition.
+   * @param FieldStorageDefinitionInterface $field_storage_definition
+   *   The field name.
+   * @param array $bundles
+   *   (Optional) the array of bundles where to check from.
    *
    * @return array
-   *   The selected plugin for the field.
+   *   The selected plugin for the field storage.
    */
-  public function getSelectedPluginForFieldStorageDefinition(FieldStorageDefinitionInterface $field_definition) {
-    $plugin_options = $this->getApplicablePluginOptions($field_definition);
-    $field_key = $field_definition->getTargetEntityTypeId() . '.' . $field_definition->getName();
-    $selected_plugin = $this->pluginsConfig->get('fields.' . $field_key);
-    // Check if the plugin stored to the fields is still applicable.
-    if (!$selected_plugin || !in_array($selected_plugin['type'], array_keys($plugin_options))) {
-      if (!empty($plugin_options)) {
-        $selected_plugin['type'] = array_keys($plugin_options)[0];
-      }
-      else {
-        $selected_plugin['type'] = 'hidden';
+  public function getDefaultPluginForFieldStorageDefinition(FieldStorageDefinitionInterface $field_storage_definition, $bundles = NULL) {
+    if (($field_storage_definition instanceof BaseFieldDefinition && $field_storage_definition->isDisplayConfigurable('view')) || $field_storage_definition instanceof FieldStorageConfig) {
+      $field_key = 'content.' . $field_storage_definition->getName() . '.type';
+      $storage = $this->entityTypeManager->getStorage('entity_view_display');
+      $query = $storage->getQuery()->condition('targetEntityType', $field_storage_definition->getTargetEntityTypeId());
+      if ($bundles) {
+        $query->condition('bundle', (array) $bundles, 'IN');
       }
+      $result = $query->exists($field_key)->range(0, 1)->execute();
+      return $result != [] ? $result : 'hidden';
+    }
+    else {
+      $view_options = (bool) $field_storage_definition->getDisplayOptions('view');
+      return $view_options ? '' : 'hidden';
     }
-    return $selected_plugin;
   }
 
   /**
@@ -139,40 +141,40 @@ class DiffBuilderManager extends DefaultPluginManager {
    *
-   * @param \Drupal\Core\Field\FieldDefinitionInterface $field_definition
-   *   The field definition.
-   * @param string $bundle
-   *   (optional) The entity bundle where to check the form display if no
-   *   setting is set for a field.
+   * @param \Drupal\Core\Field\FieldStorageDefinitionInterface $field_definition
+   *   The field storage definition.
+   * @param array $bundles
+   *   (Optional) the array of bundles where to check from.
    *
    * @return array